==> office-ui-fabric-vue-7.0.15.tgz: package/lib/tmp/components/Shimmer/ShimmerLine/ShimmerLine.styles.js <==
import { getGlobalClassNames, HighContrastSelector } from '@uifabric/styling';

const GlobalClassNames = {
  root: 'ms-ShimmerLine-root',
  topLeftCorner: 'ms-ShimmerLine-topLeftCorner',
  topRightCorner: 'ms-ShimmerLine-topRightCorner',
  bottomLeftCorner: 'ms-ShimmerLine-bottomLeftCorner',
  bottomRightCorner: 'ms-ShimmerLine-bottomRightCorner'
};
function getStyles(props) {
  // tslint:disable-next-line:deprecation
  const {
    height,
    borderStyle,
    theme
  } = props;
  const {
    semanticColors
  } = theme;
  const globalClassNames = getGlobalClassNames(GlobalClassNames, theme);
  const borderStyles = borderStyle || {};
  const sharedCornerStyles = {
    position: 'absolute',
    fill: semanticColors.bodyBackground
  };
  return {
    root: [globalClassNames.root, theme.fonts.medium, {
      height: `${height}px`,
      boxSizing: 'content-box',
      position: 'relative',
      borderTopStyle: 'solid',
      borderBottomStyle: 'solid',
      borderColor: semanticColors.bodyBackground,
      borderWidth: 0,
      selectors: {
        [HighContrastSelector]: {
          borderColor: 'Window',
          selectors: {
            '> *': {
              fill: 'Window'
            }
          }
        }
      }
    }, borderStyles],
    topLeftCorner: [globalClassNames.topLeftCorner, {
      top: '0',
      left: '0'
    }, sharedCornerStyles],
    topRightCorner: [globalClassNames.topRightCorner, {
      top: '0',
      right: '0'
    }, sharedCornerStyles],
    bottomRightCorner: [globalClassNames.bottomRightCorner, {
      bottom: '0',
      right: '0'
    }, sharedCornerStyles],
    bottomLeftCorner: [globalClassNames.bottomLeftCorner, {
      bottom: '0',
      left: '0'
    }, sharedCornerStyles]
  };
}

export { getStyles };

==> office-ui-fabric-vue-7.0.24.tgz: package/lib/tmp/components/Shimmer/ShimmerLine/ShimmerLine.styles.js <==
import { getGlobalClassNames, HighContrastSelector } from '@uifabric/styling';
import defineProperty from '../../../../node_modules/@babel/runtime/helpers/defineProperty.js';

var GlobalClassNames = {
  root: 'ms-ShimmerLine-root',
  topLeftCorner: 'ms-ShimmerLine-topLeftCorner',
  topRightCorner: 'ms-ShimmerLine-topRightCorner',
  bottomLeftCorner: 'ms-ShimmerLine-bottomLeftCorner',
  bottomRightCorner: 'ms-ShimmerLine-bottomRightCorner'
};
function getStyles(props) {
  // tslint:disable-next-line:deprecation
  var height = props.height,
      borderStyle = props.borderStyle,
      theme = props.theme;
  var semanticColors = theme.semanticColors;
  var globalClassNames = getGlobalClassNames(GlobalClassNames, theme);
  var borderStyles = borderStyle || {};
  var sharedCornerStyles = {
    position: 'absolute',
    fill: semanticColors.bodyBackground
  };
  return {
    root: [globalClassNames.root, theme.fonts.medium, {
      height: "".concat(height, "px"),
      boxSizing: 'content-box',
      position: 'relative',
      borderTopStyle: 'solid',
      borderBottomStyle: 'solid',
      borderColor: semanticColors.bodyBackground,
      borderWidth: 0,
      selectors: defineProperty({}, HighContrastSelector, {
        borderColor: 'Window',
        selectors: {
          '> *': {
            fill: 'Window'
          }
        }
      })
    }, borderStyles],
    topLeftCorner: [globalClassNames.topLeftCorner, {
      top: '0',
      left: '0'
    }, sharedCornerStyles],
    topRightCorner: [globalClassNames.topRightCorner, {
      top: '0',
      right: '0'
    }, sharedCornerStyles],
    bottomRightCorner: [globalClassNames.bottomRightCorner, {
      bottom: '0',
      right: '0'
    }, sharedCornerStyles],
    bottomLeftCorner: [globalClassNames.bottomLeftCorner, {
      bottom: '0',
      left: '0'
    }, sharedCornerStyles]
  };
}

export { getStyles };
